netapp_ontap.models.shelf_acps_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_acps_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfAcpsErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfAcpsError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `reason: Error GET`

    The reason field of the shelf_acps_error.

  `severity: str GET POST PATCH`

    The severity field of the shelf_acps_error.

    Valid choices:

    - unknown
    - notice
    - warning
    - error
    - critical
  `type: str GET POST PATCH`

    The type field of the shelf_acps_error.

    Valid choices:

    - not_applicable
    - connection_issue
    - connection_activity
    - module_error
    - shelf_error